/******************************************************************************
  USBM3069.h Linux版
  更新日:2009/12/4

  libusbm3069.so用ヘッダーファイル

  テクノウェーブ株式会社 Copyright 2005-2009
*******************************************************************************/
#ifndef _USBM3069_H_
#define _USBM3069_H_

//FTD2XX.hのインクルードが必要な場合は、このファイルより先に読み込んでください。
#ifndef FTD2XX_H //FTD2XX.hがインクルードされていない場合

typedef PVOID FT_HANDLE;
typedef ULONG FT_STATUS;

enum {
  FT_OK,
  FT_INVALID_HANDLE,
  FT_DEVICE_NOT_FOUND,
  FT_DEVICE_NOT_OPENED,
  FT_IO_ERROR,
  FT_INSUFFICIENT_RESOURCES,
  FT_INVALID_PARAMETER,
  FT_INVALID_BAUD_RATE,

  FT_DEVICE_NOT_OPENED_FOR_ERASE,
  FT_DEVICE_NOT_OPENED_FOR_WRITE,
  FT_FAILED_TO_WRITE_DEVICE,
  FT_EEPROM_READ_FAILED,
  FT_EEPROM_WRITE_FAILED,
  FT_EEPROM_ERASE_FAILED,
  FT_EEPROM_NOT_PRESENT,
  FT_EEPROM_NOT_PROGRAMMED,
  FT_INVALID_ARGS,
  FT_NOT_SUPPORTED,
  FT_OTHER_ERROR
};

#define FT_PURGE_RX 1
#define FT_PURGE_TX 2

#endif


#ifndef __TW_BASE_TYPES__
#define __TW_BASE_TYPES__
typedef PVOID TW_HANDLE;
typedef ULONG TW_STATUS;

enum {
  TW_OK,
  TW_INVALID_HANDLE,
  TW_DEVICE_NOT_FOUND,
  TW_DEVICE_NOT_OPENED,
  TW_IO_ERROR,
  TW_INSUFFICIENT_RESOURCES,
  TW_INVALID_PARAMETER,
  TW_INVALID_BAUD_RATE,

  TW_DEVICE_NOT_OPENED_FOR_ERASE,
  TW_DEVICE_NOT_OPENED_FOR_WRITE,
  TW_FAILED_TO_WRITE_DEVICE,
  TW_EEPROM_READ_FAILED,
  TW_EEPROM_WRITE_FAILED,
  TW_EEPROM_ERASE_FAILED,
  TW_EEPROM_NOT_PRESENT,
  TW_EEPROM_NOT_PROGRAMMED,
  TW_INVALID_ARGS,
  TW_NOT_SUPPORTED,
  TW_OTHER_ERROR
};
enum{
  TW_TIMEOUT = 0xffff0001, //送信または受信処理がタイムアウト
  TW_FILE_ERROR,           //ファイルに関するエラー
  TW_MEMORY_ERROR,         //メモリの確保エラー
  TW_DATA_NOT_FOUND,       //有効なデータが無い
  TW_SOCKET_ERROR,         //Socket API のエラー
  TW_ACCESS_DENIED,         //認証エラー
  TW_NOT_SUPPORTED_MODE,   //呼び出された関数は現在のモードではサポートされない
  TW_FLASH_MODE_DEVICE,    //接続したデバイスが通常モードで無いため制御できない
};

#endif

typedef char TW_CHAR;
typedef LPSTR TW_STR;
typedef LPCSTR TW_CSTR;

typedef struct _GUID {
  DWORD  Data1;
  WORD Data2;
  WORD Data3;
  BYTE  Data4[8];
} GUID;

typedef GUID UUID;

//製品情報を取得するための構造体
typedef struct {
  WORD Empty;           //必ず0とする
  WORD wRsv;            //予約
  UUID ID;            //UUID構造体(UUIDの保存)
  DWORD Number;         //任意の番号
  char Description[32]; //製品情報
  char Manufacture[32]; //製造元情報
  BYTE Reserve[40];     //予約
} USBM_PRODUCT_INFO;

//初期化オプション
#define USBM_INIT_PORT_DIR  0x00000001
#define USBM_INIT_PORT_DATA 0x00000002
#define USBM_INIT_BUS       0x00000004
#define USBM_INIT_DMA       0x00000008
#define USBM_INIT_TIMER     0x00000010
#define USBM_INIT_AD        0x00000020
#define USBM_INIT_SCI       0x00000040
#define USBM_INIT_PC        0x00000080
#define USBM_INIT_TCPY      0x00000100
#define USBM_INIT_ALL       0xffffffff

#define USBM_IF_USB			0x80000000 	//USBインタフェース

#define USBM_PURGE_RX 1
#define USBM_PURGE_TX 2

/*ステータス*/
#define USBM_STS_TIMEOUT        0x0001
#define USBM_STS_ILLEGAL_ACCESS 0x0002

/*ポートアドレス*/
#define USBM_POUT 0xffffffff  //POUT(出力専用)を示す特別のアドレス
#define USBM_P1   0x00ffffd0  //P1(入力専用)
#define USBM_P2   0x00ffffd1  //P2(入力専用)
#define USBM_P4   0x00ffffd3  //P4(入出力)
#define USBM_P5   0x00ffffd4  //P5(入力専用)
#define USBM_PA   0x00ffffd9  //PA(入出力)

//DAコンバータのアドレス
#define USBM_DA0 0x00ffff9c
#define USBM_DA1 0x00ffff9d

//外部バスのアドレス
#define USBM_AREA0_TOP 0x100000
#define USBM_AREA2_TOP 0x400000
#define USBM_AREA3_TOP 0x600000
#define USBM_AREA5_TOP 0xa00000
#define USBM_USER_AREA 0xffbf20

//バスのウェイト
#define USBM_BUS_WAIT0  0 //3ステート,ノーウェイト
#define USBM_BUS_WAIT1  1 //1ウェイト
#define USBM_BUS_WAIT2  2 //2ウェイト
#define USBM_BUS_WAIT3  3 //3ウェイト
#define USBM_BUS_2STATE 4 //2ステートアクセス

//PCピン(IRQ)を読むためのIOポートアドレス
#define USBM_PC0_ADDR 0xffffd8
#define USBM_PC1_ADDR 0xffffd8
#define USBM_PC2_ADDR 0xffffd7
#define USBM_PC3_ADDR 0xffffd7

//PCピン(IRQ)を読むためのビットマスク
#define USBM_PC0_BIT 0x10
#define USBM_PC1_BIT 0x20
#define USBM_PC2_BIT 0x02
#define USBM_PC3_BIT 0x04

//16ビットタイマクロック
#define USBM_TCLK25000  0x00  //25MHz
#define USBM_TCLK12500  0x01  //12.5MHz
#define USBM_TCLK6250   0x02  //6250kHz
#define USBM_TCLK3125   0x03  //3125kHz
#define USBM_TCLKA      0x04  //TCLKA
#define USBM_TCLKB      0x05  //TCLKB

//16ビットタイマインプットキャプチャ用エッジ設定
#define USBM_CAPT_RISE  0x04
#define USBM_CAPT_FALL  0x05
#define USBM_CAPT_BOTH  0x07

//TCPY(8ビットタイマ)専用
#define USBM_TCLK390    0x06  //390.625kHz
#define USBM_TCLK3      0x07  //3052Hz
#define USBM_TCLKUP     0x08  //外部クロック立ち上がり
#define USBM_TCLKDOWN   0x09  //外部クロック立ち下がり
#define USBM_TCLKBOTH   0x0a  //外部クロック両エッジ

//SCI
#define USBM_SCI_DATA8    0x00  //8ビットデータ
#define USBM_SCI_DATA7    0x40  //7ビットデータ
#define USBM_SCI_NOPARITY 0x00  //パリティなし
#define USBM_SCI_EVEN     0x20  //偶数パリティ
#define USBM_SCI_ODD      0x30  //奇数パリティ
#define USBM_SCI_STOP1    0x00  //1ストップビット
#define USBM_SCI_STOP2    0x08  //2ストップビット
#define USBM_SCI_BAUD300    0x02A2  //9ビット=CKS1,8ビット=CKS0,7-0ビット=BRR,
#define USBM_SCI_BAUD600    0x0250
#define USBM_SCI_BAUD1200   0x01A2
#define USBM_SCI_BAUD2400   0x0150
#define USBM_SCI_BAUD4800   0x00A2
#define USBM_SCI_BAUD9600   0x0050
#define USBM_SCI_BAUD14400  0x0035
#define USBM_SCI_BAUD19200  0x0028
#define USBM_SCI_BAUD38400  0x0013

//メモリエリアを表す定数
#define USBM_AREA0 0x01
#define USBM_AREA2 0x04
#define USBM_AREA3 0x08
#define USBM_AREA5 0x10

//パルスカウンタを表す定数
#define USBM_PC0 0x10
#define USBM_PC1 0x20
#define USBM_PC2 0x02
#define USBM_PC3 0x04
#define USBM_PC_ALL -1


#ifdef __cplusplus
extern "C" {
long _stdcall USBM_ListDevices(TW_CHAR (*pSrerial)[9] = NULL,long nSerial = 0);
long _stdcall USBM_ListDevicesByID(WORD VID, WORD PID, TW_CHAR (*pSerial)[9], long nSerial);
TW_HANDLE _stdcall USBM_OpenByUA(TW_CSTR pUA, long nUA);
TW_HANDLE _stdcall USBM_Open(TW_CSTR pSerial = NULL);
TW_HANDLE _stdcall USBM_OpenByID(WORD VID, WORD PID, TW_CSTR pSerial);

TW_STATUS _stdcall USBM_Close(TW_HANDLE hDev);

TW_STATUS _stdcall USBM_Initialize(TW_HANDLE hDev);
TW_STATUS _stdcall USBM_AddressEnable(TW_HANDLE hDev, long nBits);
TW_STATUS _stdcall USBM_CSEnable(TW_HANDLE hDev, long Area);
TW_STATUS _stdcall USBM_BusSetWait(TW_HANDLE hDev, long Area, BYTE Wait);

TW_STATUS _stdcall USBM_PortRead8(TW_HANDLE hDev, DWORD Port, BYTE *pData);
TW_STATUS _stdcall USBM_PortWrite8(TW_HANDLE hDev,DWORD Port, BYTE Data);
TW_STATUS _stdcall USBM_PortRead16(TW_HANDLE hDev, DWORD Port, WORD *pData);
TW_STATUS _stdcall USBM_PortWrite16(TW_HANDLE hDev, DWORD Port, WORD Data);
TW_STATUS _stdcall USBM_PortBWrite(TW_HANDLE hDev, DWORD Port, void *pData, long nData, long Inc = 1, BYTE Dma = FALSE);  //(変更)TRUE -> FALSE
TW_STATUS _stdcall USBM_PortBRead(TW_HANDLE hDev, DWORD Port, void *pData, long nData, long Inc = 1, BYTE Dma = FALSE);  //(変更)TRUE -> FALSE
TW_STATUS _stdcall USBM_PortSetDir(TW_HANDLE hDev, DWORD Port, BYTE Bits);
TW_STATUS _stdcall USBM_PortBCopy(TW_HANDLE hDev, DWORD SrcPort, DWORD DstPort, long nData, long SrcInc, long DstInc);
TW_STATUS _stdcall USBM_PortCopy8(TW_HANDLE hDev, DWORD SrcPort, DWORD DstPort);
TW_STATUS _stdcall USBM_PortCopy16(TW_HANDLE hDev, DWORD SrcPort, DWORD DstPort);

TW_STATUS _stdcall USBM_TimerEnable(TW_HANDLE hDev, BYTE Bits, long MDF);
TW_STATUS _stdcall USBM_TimerSetLevel(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_TimerSetPulse(TW_HANDLE hDev, long CH, WORD LtoH, WORD HtoL);
TW_STATUS _stdcall USBM_TimerSetClk(TW_HANDLE hDev, long CH, BYTE Bits);
TW_STATUS _stdcall USBM_TimerSetCnt(TW_HANDLE hDev, long CH, short Cnt);
TW_STATUS _stdcall USBM_TimerStart(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_TimerReadCnt(TW_HANDLE hDev, long CH, short *pCnt);
TW_STATUS _stdcall USBM_TimerSetCmp(TW_HANDLE hDev, short CmpA, short CmpB);
TW_STATUS _stdcall USBM_TimerSetCmpOut(TW_HANDLE hDev, long CmpReg, DWORD Port, BYTE Data);
TW_STATUS _stdcall USBM_TimerSetCmpClr(TW_HANDLE hDev, BYTE Bits);

TW_STATUS _stdcall USBM_ADRead(TW_HANDLE hDev, WORD *pData, long CH, long Scan = FALSE);
TW_STATUS _stdcall USBM_ADSetCycle(TW_HANDLE hDev, BYTE Cmp, long CLK = USBM_TCLK3125);
TW_STATUS _stdcall USBM_ADBRead(TW_HANDLE hDev, WORD *pData, DWORD nData, long CH, DWORD *pnRead = NULL);

TW_STATUS _stdcall USBM_SCISetMode(TW_HANDLE hDev, long CH, long Mode = 0x00, long Baud = USBM_SCI_BAUD9600);
TW_STATUS _stdcall USBM_SCIReadStatus(TW_HANDLE hDev, long CH, BYTE *pStatus, long *pnReceive);
TW_STATUS _stdcall USBM_SCIRead(TW_HANDLE hDev, long CH, void *pData, long nData, long *pnRead = NULL);
TW_STATUS _stdcall USBM_SCIWrite(TW_HANDLE hDev, long CH, void *pData, long nData);

TW_STATUS _stdcall USBM_PCSetCmp(TW_HANDLE hDev, long CH, long Cmp);
TW_STATUS _stdcall USBM_PCSetCnt(TW_HANDLE hDev, long CH, long Cnt);
TW_STATUS _stdcall USBM_PCReadCnt(TW_HANDLE hDev, long CH, long *pCnt);
TW_STATUS _stdcall USBM_PCSetControl(TW_HANDLE hDev, long CH, BYTE Bits);
TW_STATUS _stdcall USBM_PCSetCondBit(TW_HANDLE hDev, long CH, DWORD Port, BYTE Mask);
TW_STATUS _stdcall USBM_PCSetCmpOut(TW_HANDLE hDev, long CH, DWORD Port, BYTE Data);
TW_STATUS _stdcall USBM_PCStart(TW_HANDLE hDev, BYTE Bits);

TW_STATUS _stdcall USBM_TCPYStart(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_TCPYSetParm(TW_HANDLE hDev, long CH, DWORD SrcPort, DWORD DstPort,
                    long nCopy, long SrcInc, long DstInc, long lLoop);
TW_STATUS _stdcall USBM_TCPYSetCmp(TW_HANDLE hDev, long CH, BYTE Cmp);
TW_STATUS _stdcall USBM_TCPYSetClk(TW_HANDLE hDev, long CH, long CLK);
TW_STATUS _stdcall USBM_TCPYSetCycle(TW_HANDLE hDev, long CH, BYTE Cmp, long CLK = USBM_TCLK3125);

TW_STATUS _stdcall USBM_Write(TW_HANDLE hDev, void *pData, DWORD nData, DWORD *pWritten);
TW_STATUS _stdcall USBM_Read(TW_HANDLE hDev, void *pData, DWORD nData, DWORD *pRead);

TW_STATUS _stdcall USBM_ReadStatus(TW_HANDLE hDev, DWORD *pStat);
TW_STATUS _stdcall USBM_ReadVersion(TW_HANDLE hDev, DWORD *pVer);

TW_STATUS _stdcall USBM_Abort(TW_HANDLE hDev);

TW_STATUS _stdcall USBM_TimerStartA(TW_HANDLE hDev, BYTE Bits, long TrigPC = -1, long Repeat = FALSE, long Cmp = 1);
TW_STATUS _stdcall USBM_TimerStop(TW_HANDLE hDev, BYTE Bits, long TrigPC = -1, long Repeat = FALSE, long Cmp = 1);
TW_STATUS _stdcall USBM_DASetCycle(TW_HANDLE hDev,long CH,long Cmp,long CLK);
TW_STATUS _stdcall USBM_DASetParm(TW_HANDLE hDev,long CH,DWORD SrcPort,long nData,long lLoop);
TW_STATUS _stdcall USBM_DAReadStatus(TW_HANDLE hDev,long CH,long *pnData);
TW_STATUS _stdcall USBM_DAStart(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_DAStop(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_TCPYSetPatternCtrl(TW_HANDLE hDev, long CH, DWORD SrcPort, DWORD DstPort,
                                       long nCopy, long nSrc, long SrcInc, long Start = 0, BYTE Mask = 0xff);
TW_STATUS _stdcall USBM_TCPYSetTrig(TW_HANDLE hDev, long CH, long StartPC, long StopPC,long Repeat);
TW_STATUS _stdcall USBM_TCPYReadStatus(TW_HANDLE hDev, long CH, long *pnCopy, long *pSrcPos);
TW_STATUS _stdcall USBM_TimerSetCapture(TW_HANDLE hDev, long CH, BYTE EdgeA = USBM_CAPT_RISE, BYTE EdgeB = USBM_CAPT_RISE);
TW_STATUS _stdcall USBM_TimerReadCaptureCnt(TW_HANDLE hDev, long CH, long *pCntA, long *pCntB);
TW_STATUS _stdcall USBM_TimerSetCaptureCnt(TW_HANDLE hDev, long CH, long CntA = 0, long CntB = 0);

TW_STATUS _stdcall USBM_ADStart(TW_HANDLE hDev, long nCnv, long CH, long Scan, long lByte = FALSE, long Trig = FALSE);
TW_STATUS _stdcall USBM_ADCopy(TW_HANDLE hDev, DWORD DstPort, long nCnv, long CH,
                           long CKS, long DMA_CH, long DstInc = TRUE);
TW_STATUS _stdcall USBM_ADReadCopyStatus(TW_HANDLE hDev,long *pnCnv,long DMA_CH);
TW_STATUS _stdcall USBM_ADReadCopyBuffer(TW_HANDLE hDev, DWORD Port, WORD *pData, long nData, long Inc, BYTE Dma);
TW_STATUS _stdcall USBM_ADStopCopy(TW_HANDLE hDev, long DMA_CH);
TW_STATUS _stdcall USBM_SCISetDelimiter(TW_HANDLE hDev, long CH, char *pDelimiter, long nDelimiter);
TW_STATUS _stdcall USBM_GetQueueStatus(TW_HANDLE hDev, DWORD *pnQueue);
TW_STATUS _stdcall USBM_Purge(TW_HANDLE hDev, DWORD dwMask);
TW_STATUS _stdcall USBM_SetTimeouts(TW_HANDLE hDev, DWORD dwReadTimeout, DWORD dwWriteTimeout);
TW_STATUS _stdcall USBM_PCStartA(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_PCStop(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_TimerSetSinglePulse(TW_HANDLE hDev, long CH, long Setup, long Width, long Pos = FALSE);
FT_HANDLE _stdcall USBM_GetFTHandle(TW_HANDLE hDev);

TW_STATUS _stdcall USBM_ReadPI(TW_HANDLE hDev, USBM_PRODUCT_INFO *pInfo);
TW_STATUS _stdcall USBM_OpenByPI(TW_HANDLE *phDev, TW_CSTR pUuid, DWORD Number, long Opt = USBM_IF_ANY | USBM_LIST_UPDATE);
TW_STATUS _stdcall USBM_PortWrite8A(TW_HANDLE hDev,DWORD Port, BYTE Data, BYTE Mask);
TW_STATUS _stdcall USBM_OpenA(TW_HANDLE *phDev, TW_CSTR pIID = NULL, long Opt = USBM_IF_ANY | USBM_LIST_UPDATE);
TW_STATUS _stdcall USBM_ListDevicesA(long *pnDev, TW_STR pIID, long *pnID, long Opt);
TW_STATUS _stdcall USBM_ReadVersionA(TW_HANDLE hDev, DWORD *pVersion);
TW_STATUS _stdcall USBM_InitializeA(TW_HANDLE hDev, DWORD InitOption = USBM_INIT_ALL);

}
#else

long _stdcall USBM_ListDevices(TW_CHAR (*pSrerial)[9],long nSerial);
long _stdcall USBM_ListDevicesByID(WORD VID, WORD PID, TW_CHAR (*pSerial)[9], long nSerial);
TW_HANDLE _stdcall USBM_OpenByUA(TW_CSTR pUA, long nUA);
TW_HANDLE _stdcall USBM_Open(TW_CSTR pSerial);
TW_HANDLE _stdcall USBM_OpenByID(WORD VID, WORD PID, TW_CSTR pSerial);
TW_STATUS _stdcall USBM_Close(TW_HANDLE hDev);

TW_STATUS _stdcall USBM_Initialize(TW_HANDLE hDev);
TW_STATUS _stdcall USBM_AddressEnable(TW_HANDLE hDev, long nBits);
TW_STATUS _stdcall USBM_CSEnable(TW_HANDLE hDev, long Area);
TW_STATUS _stdcall USBM_BusSetWait(TW_HANDLE hDev, long Area, BYTE Wait);

TW_STATUS _stdcall USBM_PortRead8(TW_HANDLE hDev, DWORD Port, BYTE *pData);
TW_STATUS _stdcall USBM_PortWrite8(TW_HANDLE hDev,DWORD Port, BYTE Data);
TW_STATUS _stdcall USBM_PortRead16(TW_HANDLE hDev, DWORD Port, WORD *pData);
TW_STATUS _stdcall USBM_PortWrite16(TW_HANDLE hDev, DWORD Port, WORD Data);
TW_STATUS _stdcall USBM_PortBWrite(TW_HANDLE hDev, DWORD Port, void *pData, long nData, long Inc, BYTE Dma);
TW_STATUS _stdcall USBM_PortBRead(TW_HANDLE hDev, DWORD Port, void *pData, long nData, long Inc, BYTE Dma);
TW_STATUS _stdcall USBM_PortSetDir(TW_HANDLE hDev, DWORD Port, BYTE Bits);
TW_STATUS _stdcall USBM_PortBCopy(TW_HANDLE hDev, DWORD SrcPort, DWORD DstPort, long nData, long SrcInc, long DstInc);
TW_STATUS _stdcall USBM_PortCopy8(TW_HANDLE hDev, DWORD SrcPort, DWORD DstPort);
TW_STATUS _stdcall USBM_PortCopy16(TW_HANDLE hDev, DWORD SrcPort, DWORD DstPort);

TW_STATUS _stdcall USBM_TimerEnable(TW_HANDLE hDev, BYTE Bits, long MDF);
TW_STATUS _stdcall USBM_TimerSetLevel(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_TimerSetPulse(TW_HANDLE hDev, long CH, WORD LtoH, WORD HtoL);
TW_STATUS _stdcall USBM_TimerSetClk(TW_HANDLE hDev, long CH, BYTE Bits);
TW_STATUS _stdcall USBM_TimerSetCnt(TW_HANDLE hDev, long CH, short Cnt);
TW_STATUS _stdcall USBM_TimerStart(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_TimerReadCnt(TW_HANDLE hDev, long CH, short *pCnt);
TW_STATUS _stdcall USBM_TimerSetCmp(TW_HANDLE hDev, short CmpA, short CmpB);
TW_STATUS _stdcall USBM_TimerSetCmpOut(TW_HANDLE hDev, long CmpReg, DWORD Port, BYTE Data);
TW_STATUS _stdcall USBM_TimerSetCmpClr(TW_HANDLE hDev, BYTE Bits);

TW_STATUS _stdcall USBM_ADRead(TW_HANDLE hDev, WORD *pData, long CH, long Scan);
TW_STATUS _stdcall USBM_ADSetCycle(TW_HANDLE hDev, BYTE Cmp, long CLK);
TW_STATUS _stdcall USBM_ADBRead(TW_HANDLE hDev, WORD *pData, DWORD nData, long CH, DWORD *pnRead);

TW_STATUS _stdcall USBM_SCISetMode(TW_HANDLE hDev, long CH, long Mode, long Baud);
TW_STATUS _stdcall USBM_SCIReadStatus(TW_HANDLE hDev, long CH, BYTE *pStatus, long *pnReceive);
TW_STATUS _stdcall USBM_SCIRead(TW_HANDLE hDev, long CH, void *pData, long nData, long *pnRead);
TW_STATUS _stdcall USBM_SCIWrite(TW_HANDLE hDev, long CH, void *pData, long nData);

TW_STATUS _stdcall USBM_PCSetCmp(TW_HANDLE hDev, long CH, long Cmp);
TW_STATUS _stdcall USBM_PCSetCnt(TW_HANDLE hDev, long CH, long Cnt);
TW_STATUS _stdcall USBM_PCReadCnt(TW_HANDLE hDev, long CH, long *pCnt);
TW_STATUS _stdcall USBM_PCSetControl(TW_HANDLE hDev, long CH, BYTE Bits);
TW_STATUS _stdcall USBM_PCSetCondBit(TW_HANDLE hDev, long CH, DWORD Port, BYTE Mask);
TW_STATUS _stdcall USBM_PCSetCmpOut(TW_HANDLE hDev, long CH, DWORD Port, BYTE Data);
TW_STATUS _stdcall USBM_PCStart(TW_HANDLE hDev, BYTE Bits);

TW_STATUS _stdcall USBM_TCPYStart(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_TCPYSetParm(TW_HANDLE hDev, long CH, DWORD SrcPort, DWORD DstPort,
                    long nCopy, long SrcInc, long DstInc, long lLoop);
TW_STATUS _stdcall USBM_TCPYSetCmp(TW_HANDLE hDev, long CH, BYTE Cmp);
TW_STATUS _stdcall USBM_TCPYSetClk(TW_HANDLE hDev, long CH, long CLK);
TW_STATUS _stdcall USBM_TCPYSetCycle(TW_HANDLE hDev, long CH, BYTE Cmp, long CLK);

TW_STATUS _stdcall USBM_Write(TW_HANDLE hDev, void *pData, DWORD nData, DWORD *pWritten);
TW_STATUS _stdcall USBM_Read(TW_HANDLE hDev, void *pData, DWORD nData, DWORD *pRead);

TW_STATUS _stdcall USBM_ReadStatus(TW_HANDLE hDev, DWORD *pStat);
TW_STATUS _stdcall USBM_ReadVersion(TW_HANDLE hDev, DWORD *pVer);

TW_STATUS _stdcall USBM_Abort(TW_HANDLE hDev);

TW_STATUS _stdcall USBM_TimerStartA(TW_HANDLE hDev, BYTE Bits, long TrigPC, long Repeat, long Cmp);
TW_STATUS _stdcall USBM_TimerStop(TW_HANDLE hDev, BYTE Bits, long TrigPC, long Repeat, long Cmp);
TW_STATUS _stdcall USBM_DASetCycle(TW_HANDLE hDev,long CH,long Cmp,long CLK);
TW_STATUS _stdcall USBM_DASetParm(TW_HANDLE hDev,long CH,DWORD SrcPort,long nData,long lLoop);
TW_STATUS _stdcall USBM_DAReadStatus(TW_HANDLE hDev,long CH,long *pnData);
TW_STATUS _stdcall USBM_DAStart(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_DAStop(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_TCPYSetPatternCtrl(TW_HANDLE hDev, long CH, DWORD SrcPort, DWORD DstPort,
                                       long nCopy, long nSrc, long SrcInc, long Start, BYTE Mask);
TW_STATUS _stdcall USBM_TCPYSetTrig(TW_HANDLE hDev, long CH, long StartPC, long StopPC,long Repeat);
TW_STATUS _stdcall USBM_TCPYReadStatus(TW_HANDLE hDev, long CH, long *pnCopy, long *pSrcPos);
TW_STATUS _stdcall USBM_TimerSetCapture(TW_HANDLE hDev, long CH, BYTE EdgeA, BYTE EdgeB);
TW_STATUS _stdcall USBM_TimerReadCaptureCnt(TW_HANDLE hDev, long CH, long *pCntA, long *pCntB);
TW_STATUS _stdcall USBM_TimerSetCaptureCnt(TW_HANDLE hDev, long CH, long CntA, long CntB);

TW_STATUS _stdcall USBM_ADStart(TW_HANDLE hDev, long nCnv, long CH, long Scan, long lByte, long Trig);
TW_STATUS _stdcall USBM_ADCopy(TW_HANDLE hDev, DWORD DstPort, long nCnv, long CH,
                           long CKS, long DMA_CH, long DstInc);
TW_STATUS _stdcall USBM_ADReadCopyStatus(TW_HANDLE hDev,long *pnCnv,long DMA_CH);
TW_STATUS _stdcall USBM_ADReadCopyBuffer(TW_HANDLE hDev, DWORD Port, WORD *pData, long nData, long Inc, BYTE Dma);
TW_STATUS _stdcall USBM_ADStopCopy(TW_HANDLE hDev, long DMA_CH);
TW_STATUS _stdcall USBM_SCISetDelimiter(TW_HANDLE hDev, long CH, char *pDelimiter, long nDelimiter);
TW_STATUS _stdcall USBM_GetQueueStatus(TW_HANDLE hDev, DWORD *pnQueue);
TW_STATUS _stdcall USBM_Purge(TW_HANDLE hDev, DWORD dwMask);
TW_STATUS _stdcall USBM_SetTimeouts(TW_HANDLE hDev, DWORD dwReadTimeout, DWORD dwWriteTimeout);
TW_STATUS _stdcall USBM_PCStartA(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_PCStop(TW_HANDLE hDev, BYTE Bits);
TW_STATUS _stdcall USBM_TimerSetSinglePulse(TW_HANDLE hDev, long CH, long Setup, long Width, long Pos);
FT_HANDLE _stdcall USBM_GetFTHandle(TW_HANDLE hDev);

TW_STATUS _stdcall USBM_ReadPI(TW_HANDLE hDev, USBM_PRODUCT_INFO *pInfo);
TW_STATUS _stdcall USBM_OpenByPI(TW_HANDLE *phDev, TW_CSTR pUuid, DWORD Number, long Opt);
TW_STATUS _stdcall USBM_PortWrite8A(TW_HANDLE hDev,DWORD Port, BYTE Data, BYTE Mask);
TW_STATUS _stdcall USBM_OpenA(TW_HANDLE *phDev, TW_CSTR pIID, long Opt);
TW_STATUS _stdcall USBM_ListDevicesA(long *pnDev, TW_STR pIID, long *pnID, long Opt);
TW_STATUS _stdcall USBM_ReadVersionA(TW_HANDLE hDev, DWORD *pVersion);
TW_STATUS _stdcall USBM_InitializeA(TW_HANDLE hDev, DWORD InitOption);

#endif


#endif /*_USBM3069_H_*/
